"""Climax configuration file."""

# !/usr/bin/env python
# -*- coding: utf-8 -*-

# builtins
import datetime

# externals
import numpy as np

# locals
from climax.core.constants import PREDICTANDS

# -----------------------------------------------------------------------------
# ERA5 downscaling configuration ----------------------------------------------
# -----------------------------------------------------------------------------

# ERA5 predictor variables on pressure levels
# ERA5_P_PREDICTORS = ERA5_P_VARIABLES

# # ERA5 predictor variables on single levels
# ERA5_S_PREDICTORS = ERA5_S_VARIABLES

# # ERA5 predictor variables
# ERA5_PREDICTORS = ERA5_VARIABLES

# ERA5 pressure levels
ERA5_PLEVELS = [500, 850]

# -----------------------------------------------------------------------------
# Observations ----------------------------------------------------------------
# -----------------------------------------------------------------------------

# target variable: check if target variable is valid
PREDICTAND = 'tasmin'
assert PREDICTAND in PREDICTANDS

# -----------------------------------------------------------------------------
# Calibration period  ---------------------------------------------------------
# -----------------------------------------------------------------------------

# calibration period: training and validation
CALIB_PERIOD = np.arange(
    datetime.datetime.strptime('1981-01-01', '%Y-%m-%d').date(),
    datetime.datetime.strptime('2011-01-01', '%Y-%m-%d').date())

# -----------------------------------------------------------------------------
# Model training configuration ------------------------------------------------
# -----------------------------------------------------------------------------

# whether to randomly shuffle time steps or to conserve time series for model
# training
SHUFFLE = False

# batch size: number of time steps processed by the net in each iteration
BATCH_SIZE = 64

# learning rate
LR = 0.001

# network training configuration
TRAIN_CONFIG = {
    'checkpoint_state': {},
    'epochs': 50,
    'save': True,
    'early_stop': True,
    'patience': 25,
    'multi_gpu': True,
    'classification': False
    }
